@@ -1,7 +1,7 @@
 from hcat.detect import _detect
 from hcat.segment import _segment
+from hcat.detect_gui import gui
 
-import os.path
 import glob
 
 import click
@@ -13,12 +13,14 @@ warnings.filterwarnings("ignore")
 This is the main entry point to all analysis scripts. Each analysis script is found in hcat.
 """
 
+
 @click.group(invoke_without_command=True)
 @click.pass_context
 def cli(ctx):
     if ctx.invoked_subcommand is None:
         """ Default subcommand is running full analysis """
-        segment()
+        gui().main_loop()
+
 
 @cli.command()
 @click.argument('f', default=None)
@@ -33,35 +35,53 @@ def segment(f: str, channel: int, intensity_reject_threshold: float,
             dtype: Optional[str],
             unet: bool, cellpose: bool, no_post: bool,
             figure: Optional[bool]) -> None:
+    raise NotImplementedError('Segmentation currently in not supported.')
+    # files = glob.glob(f)
+    # for filename in files:
+    #     try:
+    #         _segment(f=filename, channel=channel, intensity_reject_threshold=intensity_reject_threshold,
+    #                  dtype=dtype, unet=unet, cellpose=cellpose, no_post=no_post, figure=figure)
+    #     except Exception:
+    #         print(f'Error in file: {filename}')
+
+    # return None
 
-    _segment(f=f, channel=channel, intensity_reject_threshold=intensity_reject_threshold,
-             dtype=dtype, unet=unet, cellpose=cellpose, no_post=no_post, figure=figure)
-    return None
 
 @cli.command()
 @click.argument('f', default=None)
 @click.option('--curve_path', default=None, help='CSV path of manually annotated cochlear curvature')
 @click.option('--cell_detection_threshold', default=0.85, help='Threshold (between 0 and 1) of cell detection.')
+@click.option('--nms_threshold', default=0.1, help='Allowable overlap between prediction boxes.')
 @click.option('--dtype', default=None, help='dtype of input image')
 @click.option('--save_xml', is_flag=True, help='Threshold (between 0 and 1) of cell detection.')
+@click.option('--save_png', is_flag=True, help='Save a png for annoation purposes.')
 @click.option('--save_fig', is_flag=True, help='Threshold (between 0 and 1) of cell detection.')
+@click.option('--normalize', is_flag=True, help='Threshold (between 0 and 1) of cell detection.')
 @click.option('--pixel_size', default=None, help='Pixel size in nm')
 @click.option('--cell_diameter', default=None, help='Cell diameter in pixels')
-@click.option('--batch', is_flag=True, help='Evaluate every image in folder')
-def detect(f: str, curve_path, cell_detection_threshold, save_xml, save_fig, pixel_size, dtype, cell_diameter, batch):
+def detect(f: str, curve_path, cell_detection_threshold, nms_threshold, save_xml, save_png,
+           save_fig, normalize, pixel_size, dtype, cell_diameter):
 
+    cell_diameter = float(cell_diameter) if cell_diameter is not None else None
     # Evaluate a single image
-    if os.path.isfile(f):
-        _detect(f=f, curve_path=curve_path, cell_detection_threshold=cell_detection_threshold,
-                save_xml=save_xml, save_fig=save_fig, pixel_size=pixel_size, cell_diameter=cell_diameter, dtype=dtype)
 
-    # Evaluate all images in a folder
-    elif os.path.isdir(f) and batch:
-        for f in glob.glob(f+'*/*/*.lif'):
-            _detect(f=f, curve_path=curve_path, cell_detection_threshold=cell_detection_threshold,
-                    save_xml=save_xml, save_fig=save_fig, pixel_size=pixel_size, cell_diameter=cell_diameter, dtype=dtype)
-    else:
-        print('\x1b[1;31;40m' + 'ERROR: Multi image cochlear analysis is currently not supported...' + '\x1b[0m')
+    files = glob.glob(f)
+    for filename in files:
+        try:
+            _detect(f=filename,
+                    curve_path=curve_path,
+                    cell_detection_threshold=cell_detection_threshold,
+                    nms_threshold=nms_threshold,
+                    save_png=save_png,
+                    save_xml=save_xml,
+                    save_fig=save_fig,
+                    normalize=normalize,
+                    pixel_size=pixel_size,
+                    cell_diameter=cell_diameter,
+                    dtype=dtype)
+        except Exception as e:
+            print(f'Critical Error! Aborting - {filename}')
+            raise e
 
 
 if __name__ == '__main__':
